@@ -3,7 +3,7 @@ import math
 import collections
 from .value_checks import (is_a_date, is_a_int, is_a_bool, is_a_float,
     is_a_coord, is_a_coord_pair, is_a_country, is_a_city, is_a_region,
-    is_a_address)
+    is_a_address, is_a_text)
 
 
 """Guesses likelikhood that a column is of the requested type based on its
@@ -18,9 +18,11 @@ values.
 """
 def column_probability_for_type(values, for_type, pos=None, key=None):
     if for_type == 'category':
-        return category_probability(values)
+        return category_probability(values, key=key, pos=pos)
     elif for_type == 'id':
-        return id_probability(values)
+        return id_probability(values, key=key, pos=pos)
+    elif for_type == 'proportion':
+        return proportion_probability(values, key=key)
 
     type_checkers = {
         'date': is_a_date,
@@ -32,7 +34,8 @@ def column_probability_for_type(values, for_type, pos=None, key=None):
         'city': is_a_city,
         'region': is_a_region,
         'country': is_a_country,
-        'address': is_a_address
+        'address': is_a_address,
+        'text': is_a_text
     }
 
     is_type = 0
@@ -77,20 +80,18 @@ def id_probability(values, key=None, pos=None):
 :param pos: the column position (optiona - eg 0 for the first column)
 """
 def proportion_probability(values, key=None, pos=None):
-    prob = 0
-
-    if column_probability_for_type(values, 'int') == 1 or column_probability_for_type(values, 'float') == 1:
-
-        if sum(values) == 1 or sum(values) == 100:
-            prob += 1
-        else:
-            return 0
-
-        return prob
-
+    if column_probability_for_type(values, 'int') == 1:
+        values = [int(v) for v in values]
+    elif column_probability_for_type(values, 'float') == 1:
+        values = [float(v) for v in values]
     else:
         return 0
 
+    if sum(values) == 1 or sum(values) == 100:
+        return 1
+
+    return 0
+
 
 """The likelihood that a given list of values is a category. A category column
 is assumed to have the following properties:
@@ -201,7 +202,7 @@ def detect_delimiter(values):
     if len(non_empty) < len(values) / 2:
         return None
 
-    delimeters = [',','|','/']
+    delimiters = [',','|','/']
 
     # 50 is a wild guess, should be refined
     short_enough = [v for v in non_empty if len(v) < 50]
@@ -209,15 +210,15 @@ def detect_delimiter(values):
         return None
 
     # number of records with each type of delimiter
-    delimeter_count = [0] * len(delimeters)
-    for i,d in enumerate(delimeters):
+    delimeter_count = [0] * len(delimiters)
+    for i,d in enumerate(delimiters):
         delimeter_count[i] = len([v for v in non_empty if d in v])
 
     # if more than half the records contain one type of delimeter, it wins
     possible_delimeters = []
     for i,dc in enumerate(delimeter_count):
         if dc > len(non_empty) / 2:
-            possible_delimeters.append(delimeters[i])
+            possible_delimeters.append(delimiters[i])
 
     if len(possible_delimeters) != 1:
         return None
@@ -226,7 +227,7 @@ def detect_delimiter(values):
 
     def average(s): return sum(s) * 1.0 / len(s)
 
-    # get average worth length and standard deviation
+    # get average word length and standard deviation
     categories = list(itertools.chain.from_iterable([i.split(delimiter) for i in non_empty]))
     word_lengths = [len(w) for w in categories]
     avg_word_length = average(word_lengths)
